<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="de">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="131"/>
        <source>MX Package Installer</source>
        <translation>MX-Paketinstallation</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Beliebte Anwendungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Category</source>
        <translation>Kategorie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Package</source>
        <translation>Paket</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Info</source>
        <translation>Info</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="420"/>
        <location filename="../mainwindow.ui" line="817"/>
        <location filename="../mainwindow.ui" line="1074"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Beliebte Pakete verwalten&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <location filename="../mainwindow.ui" line="190"/>
        <location filename="../mainwindow.ui" line="686"/>
        <location filename="../mainwindow.ui" line="1099"/>
        <location filename="../mainwindow.ui" line="1208"/>
        <source>search</source>
        <translation>Suche </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.ui" line="699"/>
        <location filename="../mainwindow.ui" line="1167"/>
        <location filename="../mainwindow.ui" line="1431"/>
        <source>= Installed packages</source>
        <translation>= Installierte Pakete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Enabled Repos</source>
        <translation>Aktivierte Paketquellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remove all the packages that are marked as &amp;quot;autoremovable&amp;quot;. If you want to manage them, select Autoremovable from drop-down selection box.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>Alle Pakete entfernen, die als &amp;quot;automatisch entfernbar&amp;quot; markiert sind. Wählen Sie &quot;Automatisch entfernbar&quot; aus der Dropdown-Auswahlbox, wenn Sie die Pakete verwalten möchten.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>Autoremove packages</source>
        <translation>Pakete automatisch entfernen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="1324"/>
        <source>Upgrade All</source>
        <translation>Alle aktualisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.ui" line="926"/>
        <source>Installed:</source>
        <translation>Installiert:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <location filename="../mainwindow.ui" line="540"/>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Total packages:</source>
        <translation>Pakete gesamt:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <location filename="../mainwindow.ui" line="662"/>
        <location filename="../mainwindow.ui" line="987"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>Auch »empfohlene« Pakete installieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <location filename="../mainwindow.ui" line="577"/>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Upgradable:</source>
        <translation>Aktualisierbar:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <location filename="../mainwindow.ui" line="584"/>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Hide library and developer packages</source>
        <translation>Bibliotheken und Entwicklerpakete verstecken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <location filename="../mainwindow.ui" line="633"/>
        <location filename="../mainwindow.ui" line="1006"/>
        <location filename="../mainwindow.ui" line="1524"/>
        <source>Refresh list</source>
        <translation>Liste aktualisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <location filename="../mainwindow.ui" line="758"/>
        <location filename="../mainwindow.ui" line="1129"/>
        <location filename="../mainwindow.ui" line="1479"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pakete anhand ihres Status filtern.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <location filename="../mainwindow.ui" line="488"/>
        <location filename="../mainwindow.ui" line="761"/>
        <location filename="../mainwindow.ui" line="765"/>
        <location filename="../mainwindow.ui" line="1132"/>
        <location filename="../mainwindow.ui" line="1136"/>
        <location filename="../mainwindow.cpp" line="3054"/>
        <source>All packages</source>
        <translation>Alle Pakete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <location filename="../mainwindow.ui" line="770"/>
        <location filename="../mainwindow.ui" line="1141"/>
        <location filename="../mainwindow.cpp" line="3074"/>
        <source>Installed</source>
        <translation>Installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <location filename="../mainwindow.ui" line="775"/>
        <location filename="../mainwindow.ui" line="1146"/>
        <location filename="../mainwindow.cpp" line="3075"/>
        <source>Upgradable</source>
        <translation>Aktualisierbar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="503"/>
        <location filename="../mainwindow.ui" line="780"/>
        <location filename="../mainwindow.ui" line="1151"/>
        <location filename="../mainwindow.ui" line="1516"/>
        <location filename="../mainwindow.cpp" line="3039"/>
        <location filename="../mainwindow.cpp" line="3076"/>
        <location filename="../mainwindow.cpp" line="3178"/>
        <location filename="../mainwindow.cpp" line="3179"/>
        <source>Not installed</source>
        <translation>Nicht installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <location filename="../mainwindow.ui" line="785"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <location filename="../mainwindow.cpp" line="2574"/>
        <location filename="../mainwindow.cpp" line="3010"/>
        <location filename="../mainwindow.cpp" line="3077"/>
        <location filename="../mainwindow.cpp" line="3163"/>
        <source>Autoremovable</source>
        <translation>Automatisch entfernbar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <location filename="../mainwindow.ui" line="727"/>
        <location filename="../mainwindow.ui" line="855"/>
        <source>= Upgradable package. Newer version available in selected repository.</source>
        <translation>= Aktualisierbares Paket. Eine neuere Version ist bei der ausgewählten Paketquelle verfügbar.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <location filename="../mainwindow.ui" line="802"/>
        <location filename="../mainwindow.ui" line="1059"/>
        <source>Package Name</source>
        <translation>Paketname</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>MX Test Repo</source>
        <translation>MX-Test-Paketquellen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <location filename="../mainwindow.ui" line="807"/>
        <location filename="../mainwindow.ui" line="1064"/>
        <source>Repo Version</source>
        <translation>Repository-Version</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="415"/>
        <location filename="../mainwindow.ui" line="812"/>
        <location filename="../mainwindow.ui" line="1069"/>
        <source>Installed Version</source>
        <translation>Installierte Version</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="837"/>
        <source>Debian Backports</source>
        <translation>Debian Backports</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1190"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1447"/>
        <location filename="../mainwindow.ui" line="1451"/>
        <location filename="../mainwindow.cpp" line="115"/>
        <location filename="../mainwindow.cpp" line="116"/>
        <source>For all users</source>
        <translation>Für alle Benutzer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>For current user</source>
        <translation>Für aktuellen Benutzer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1541"/>
        <source>Remote (repo):</source>
        <translation>Flatpak-Paketquellen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <location filename="../mainwindow.ui" line="1486"/>
        <location filename="../mainwindow.cpp" line="3021"/>
        <source>All apps</source>
        <translation>Alle Anwendungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1491"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>All runtimes</source>
        <translation>Alle Laufzeitbibliotheken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1496"/>
        <location filename="../mainwindow.cpp" line="3033"/>
        <source>All available</source>
        <translation>Alle verfügbaren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1501"/>
        <location filename="../mainwindow.cpp" line="3018"/>
        <source>Installed apps</source>
        <translation>Installierte Anwendungen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1506"/>
        <location filename="../mainwindow.cpp" line="3015"/>
        <source>Installed runtimes</source>
        <translation>Installierte Laufzeitbibliotheken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1511"/>
        <location filename="../mainwindow.cpp" line="3037"/>
        <location filename="../mainwindow.cpp" line="3171"/>
        <location filename="../mainwindow.cpp" line="3172"/>
        <source>All installed</source>
        <translation>Es wurde alles installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1303"/>
        <source>Total items </source>
        <translation>Gesamtanzahl</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1317"/>
        <source>Installed apps:</source>
        <translation>Installierte Anwendungen:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1369"/>
        <source>Advanced</source>
        <translation>Fortgeschritten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1398"/>
        <source>Total installed size:</source>
        <translation>Gesamte Installationsgröße:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1412"/>
        <source>Remove unused runtimes</source>
        <translation>Nicht benötigte Laufzeitbibliotheken entfernen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1249"/>
        <source>Short Name</source>
        <translation>Kurzname</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1254"/>
        <source>Full Package Name</source>
        <translation>Völlständiger Paketname</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1264"/>
        <source>Size</source>
        <translation>Größe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1558"/>
        <location filename="../mainwindow.cpp" line="2717"/>
        <location filename="../mainwindow.cpp" line="2935"/>
        <source>Console Output</source>
        <translation>Konsolenausgabe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1564"/>
        <source>Enter</source>
        <translation>Eingabetaste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1574"/>
        <source>Respond here, or just press Enter</source>
        <translation>Hier antworten oder einfach die Eingabetaste betätigen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1633"/>
        <location filename="../mainwindow.cpp" line="1249"/>
        <location filename="../mainwindow.cpp" line="3064"/>
        <location filename="../mainwindow.cpp" line="3072"/>
        <location filename="../mainwindow.cpp" line="3162"/>
        <location filename="../mainwindow.cpp" line="3168"/>
        <location filename="../mainwindow.cpp" line="3463"/>
        <source>Install</source>
        <translation>Installieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1639"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>Quit application</source>
        <translation>Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1667"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1699"/>
        <source>About this application</source>
        <translation>Über diese Anwendung</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1702"/>
        <source>About...</source>
        <translation>Über...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1708"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1746"/>
        <source>Display help </source>
        <translation>Hilfe anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1749"/>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1755"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1771"/>
        <source>Uninstall</source>
        <translation>Deinstallieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1777"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>Uninstalling packages...</source>
        <translation>Deinstalliere Pakete...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Running pre-uninstall operations...</source>
        <translation>Deinstallation wird vorbereitet...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Running post-uninstall operations...</source>
        <translation>Vordefinierte Aktionen nach dem Deinstallieren werden ausgeführt ....</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Refreshing sources...</source>
        <translation>Quellen werden neu eingelesen....</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <location filename="../mainwindow.cpp" line="1297"/>
        <location filename="../mainwindow.cpp" line="1432"/>
        <location filename="../mainwindow.cpp" line="1601"/>
        <location filename="../mainwindow.cpp" line="1666"/>
        <location filename="../mainwindow.cpp" line="1981"/>
        <location filename="../mainwindow.cpp" line="2121"/>
        <location filename="../mainwindow.cpp" line="2567"/>
        <location filename="../mainwindow.cpp" line="2586"/>
        <location filename="../mainwindow.cpp" line="2693"/>
        <location filename="../mainwindow.cpp" line="2709"/>
        <location filename="../mainwindow.cpp" line="2805"/>
        <location filename="../mainwindow.cpp" line="2838"/>
        <location filename="../mainwindow.cpp" line="3271"/>
        <location filename="../mainwindow.cpp" line="3347"/>
        <location filename="../mainwindow.cpp" line="3377"/>
        <location filename="../mainwindow.cpp" line="3479"/>
        <location filename="../mainwindow.cpp" line="3519"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Ein Problem ist beim Aktualisieren der Quellen aufgetreten. Einige Quellen könnten nicht aktualisiert worden sein. Für mehr Informationen siehe:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>Could not determine Debian version. Please select your version:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Debian Version</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Cancel</source>
        <translation>Abbruch</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="700"/>
        <source>Please wait...</source>
        <translation>Bitte warten...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1113"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Sie sind im Begriff, die MX-Testpaketquelle zu nutzen, dessen Pakete nur zu Testzwecken verfügbar sind. Es ist möglich, daß diese Pakete das System unbrauchbar machen; deshalb wird empfohlen, eine Sicherung des Systems anzulegen und immer nur einzelne Pakete zu installieren oder zu aktualisieren. Bitte geben Sie auch Rückmeldungen im Forum ab, damit das jeweilige Paket evaluiert werden kann, bevor es in die stabile Version übernommen wird.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1122"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Sie sind dabei, Debian Backports zu benutzen, welches Pakete aus der nächsten Debian Freigabe (&quot;testing&quot;) enthält, die zur Nutzung in Debian Stable angepasst und neu kompiliert wurden. Diese Pakete konnten nicht so intensiv wie in der stabilen Freigabe von Debian und MX Linux getestet werden und werden ohne Garantie und mit dem Risiko der Inkompatibilität zu Komponenten aus Debian Stable zur Verfügung gestellt. Mit Vorsicht verwenden! </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1130"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>MX Linux enthält diese Paketquelle von Flatpaks nur aus Gründen der Benutzerfreundlichkeit und ist nicht verantwortlich für die Funktionalität der einzelnen Flatpaks. Nähere Infos dazu stehen im Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1138"/>
        <location filename="../mainwindow.cpp" line="3507"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1142"/>
        <source>Do not show this message again</source>
        <translation>Diese Meldung nicht mehr anzeigen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1246"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1262"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Die folgenden Pakete wurden ausgewählt. Zur Anzeige einer Übersicht aller Änderungen klicken Sie bitte auf »Details anzeigen«.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1298"/>
        <location filename="../mainwindow.cpp" line="1433"/>
        <location filename="../mainwindow.cpp" line="1667"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Internet ist nicht verfügbar. Die  Paketeliste kann nicht heruntergeladen werden.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1301"/>
        <source>Installing packages...</source>
        <translation>Installiere Pakete...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1359"/>
        <source>Post-processing...</source>
        <translation>Nachbearbeitung...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1391"/>
        <source>Pre-processing for </source>
        <translation>Vorverarbeitung für</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1405"/>
        <source>Installing </source>
        <translation>Installiere</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1412"/>
        <source>Post-processing for </source>
        <translation>Nachbearbeitung für</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1602"/>
        <source>There was an error downloading or writing the file: %1. Please check your internet connection and free space on your drive</source>
        <translation>Beim Herunterladen oder Speichern der Datei %1 ist ein Fehler aufgetreten. Bitte prüfen Sie Ihre Internetverbindung und den freien Speicherplatz auf dem Speichermedium sowie ihre Zugriffsberechtigungen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <source>Downloading package info...</source>
        <translation>Lade Paketinformationen herunter...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1982"/>
        <source>dpkg-query command returned an error. Please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation>Der Befehl &quot;dpkg-query&quot; hat einen Fehler gemeldet. Führen Sie bitte &quot;dpkg-query -W&quot; im Terminal aus und prüfen Sie das Ergebnis.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2122"/>
        <source>dpkg-query command returned an error, please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2243"/>
        <location filename="../mainwindow.cpp" line="2345"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <source>Package info</source>
        <translation>Paketinformationen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2260"/>
        <location filename="../mainwindow.cpp" line="3411"/>
        <source>More &amp;info...</source>
        <translation>Weitere &amp;Informationen...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2291"/>
        <source>Packages to be installed: </source>
        <translation>Zu installierende Pakete:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2551"/>
        <location filename="../mainwindow.cpp" line="2563"/>
        <location filename="../mainwindow.cpp" line="2583"/>
        <location filename="../mainwindow.cpp" line="2668"/>
        <location filename="../mainwindow.cpp" line="2690"/>
        <location filename="../mainwindow.cpp" line="3268"/>
        <location filename="../mainwindow.cpp" line="3343"/>
        <location filename="../mainwindow.cpp" line="3371"/>
        <location filename="../mainwindow.cpp" line="3475"/>
        <source>Done</source>
        <translation>Erledigt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2551"/>
        <location filename="../mainwindow.cpp" line="2563"/>
        <location filename="../mainwindow.cpp" line="2583"/>
        <location filename="../mainwindow.cpp" line="2668"/>
        <location filename="../mainwindow.cpp" line="2690"/>
        <location filename="../mainwindow.cpp" line="2706"/>
        <location filename="../mainwindow.cpp" line="3268"/>
        <location filename="../mainwindow.cpp" line="3343"/>
        <location filename="../mainwindow.cpp" line="3371"/>
        <location filename="../mainwindow.cpp" line="3475"/>
        <location filename="../mainwindow.cpp" line="3516"/>
        <source>Processing finished successfully.</source>
        <translation>Die Installation war erfolgreich.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2568"/>
        <location filename="../mainwindow.cpp" line="2587"/>
        <location filename="../mainwindow.cpp" line="3272"/>
        <location filename="../mainwindow.cpp" line="3348"/>
        <location filename="../mainwindow.cpp" line="3378"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Bei der Installation trat ein Problem auf; siehe Konsolenausgabe </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2597"/>
        <source>About %1</source>
        <translation>Über %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2598"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2600"/>
        <source>Package Installer for MX Linux</source>
        <translation>Paket-Installation für MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2602"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2603"/>
        <source>%1 License</source>
        <translation>%1 Lizenz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2615"/>
        <source>%1 Help</source>
        <translation>%1 Hilfe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2693"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Es gab ein Problem beim Deinstallieren. Bitte die Ausgabe überprüfen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2706"/>
        <location filename="../mainwindow.cpp" line="3516"/>
        <source>Success</source>
        <translation>Erfolg</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2709"/>
        <location filename="../mainwindow.cpp" line="3519"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Beim Deinstallieren des Programms trat ein Problem auf</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2806"/>
        <location filename="../mainwindow.cpp" line="2839"/>
        <source>Could not download the list of packages. Please check your APT sources.</source>
        <translation>Die Liste der Pakete konnte nicht heruntergeladen werden. Bitte überprüfen Sie Ihre APT-Quellen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2876"/>
        <location filename="../mainwindow.cpp" line="2918"/>
        <source>Flatpak not installed</source>
        <translation>Flatpak nicht installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2877"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Flatpak ist noch nicht installiert.
Mit OK die Installation einleiten?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2918"/>
        <source>Flatpak was not installed</source>
        <translation>Flatpak wurde nicht installiert</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2939"/>
        <source>Needs re-login</source>
        <translation>Erneutes Anmelden erforderlich</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2940"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Erst nach dem Ab-/Neuanmelden werden installierte Anwendungen im Menü sichtbar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3064"/>
        <location filename="../mainwindow.cpp" line="3072"/>
        <location filename="../mainwindow.cpp" line="3164"/>
        <source>Mark keep</source>
        <translation>Zum Behalten markieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3162"/>
        <source>Upgrade</source>
        <translation>Aktualisieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3300"/>
        <source>Quit?</source>
        <translation>Beenden? </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3301"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Der Prozess läuft noch, das Beenden könnte das System in einen instabilen Zustand versetzen.&lt;p&gt;&lt;b&gt;Sind Sie sicher, daß Sie das MX-Paketinstallationsprogrammn beenden möchten?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3463"/>
        <source>Reinstall</source>
        <translation>Erneut installieren</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3480"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>Während des letzten Vorgangs wurde ein Problem festgestellt. Bitte überprüfen Sie die Konsolenausgabe.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3508"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>Der Vorgang ist potentiell riskant
Bitte überprüfen Sie sorgfältig die Liste der zum Entfernen vorgesehenen Pakete.</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="16"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Flatpak-Paketquellen verwalten</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>Für alle Benutzer</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>Für aktuellen Benutzer</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>enter Flatpak remote URL</source>
        <translation>Flatpak-Paketquellen-URL eingeben</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="38"/>
        <source>enter Flatpakref location to install app</source>
        <translation>Flatpakref Pfad/URL zur Installation eingeben</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="40"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Flatpak-Paketquellen hinzufügen oder entfernen, oder Installation von Flatpak-Apps mit Flatpakref (Pfad/URL)</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Remove remote</source>
        <translation>Flatpak-Paketquelle entfernen</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Add remote</source>
        <translation>Flatpak-Paketquelle hinzufügen</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Install app</source>
        <translation>Anwendung installieren</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="64"/>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation>Nicht entfernbar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="82"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Flathub ist die Flatpak-Haupt-Paketquelle und kann nicht entfernt werden</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Error adding remote</source>
        <translation>Fehler beim Hinzufügen der Paketquelle</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Konnte die Paketquelle nicht hinzufügen - der Befehl endete mit einem Fehler. Bitte die Paketquellen-URL überprüfen und nochmal versuchen.</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Success</source>
        <translation>Erfolg</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Remote added successfully</source>
        <translation>Flatpak-Paketquelle erfolgreich hinzugefügt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="71"/>
        <source>License</source>
        <translation>Lizenz</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <location filename="../about.cpp" line="82"/>
        <source>Changelog</source>
        <translation>Änderungsprotokoll</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="50"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="51"/>
        <source>Dpkg/apt database is locked by another program: %1
Close the program, or wait until it is done processing and try again.</source>
        <translation>Die dpkg/apt-Datenbank ist durch ein anderes Programm gesperrt: %1
Bitte das Programm schließen oder warten, bis es fertig ist und es dann erneut versuchen.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>MX Package Installer is a tool used for managing packages on MX Linux
    - installs popular programs from different sources
    - installs programs from the MX Test repo
    - installs programs from Debian Backports repo
    - installs flatpaks</source>
        <translation>MX-Paketinstallation ist eine Anwendung zur Verwaltung von Paketen in MX-Linux
    - installiert beliebte Programme aus verschiedenen Quellen
    - installiert Programme aus der MX-Test-Paketquelle
    - installiert Programme aus der Debian-Backports-Paketquelley
    - installiert Flatpak-Dateien</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>Skip online check if it falsely reports lack of internet access.</source>
        <translation>Den Online-Check überspringen, wenn fälschlicherweise gemeldet wird, dass kein Internetzugang vorhanden ist.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="98"/>
        <location filename="../main.cpp" line="106"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Sie sind als Administrator am System angemeldet. Bitte melden Sie sich ab und dann als normaler Benutzer wieder an, um dieses Programm zu verwenden.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="107"/>
        <source>You must run this program with admin access.</source>
        <translation>Diese Anwendung muss mit Administratorrechten ausgeführt werden.</translation>
    </message>
</context>
</TS>